@@ -24,7 +24,7 @@
 #  or by writing to the  Free Software Foundation, Inc., 59 Temple Place,
 #                  Suite 330, Boston, MA 02111-1307 USA
 # -------------------------------------------------------------------------
-# $Revision: 739 $
+# $Revision: 767 $
 # =========================================================================
 
 irace.license <-
@@ -106,8 +106,8 @@ hookEvaluate  ""  --hook-evaluate  "" "Optional script that provides a numeric v
 "nbExperimentsPerIteration"  ""  "--experiments-per-iteration"  0  "Number of experiments per iteration." 
 "sampleInstances"  ""  "--sample-instances"  1  "Sample the instances or take them always in the same order." 
 "testType"  ""  "--test-type"  "F-test"  "Specifies the statistical test type: F-test or t-test." 
-"firstTest"  ""  "--first-test"  5    "Specifies after how many instances should be performed the first test." 
-"eachTest"  ""  "--each-test"  1    "Specifies after how many instances should be performed each test." 
+"firstTest"  ""  "--first-test"  5    "Specifies how many instances are seen before the first test."
+"eachTest"  ""  "--each-test"  1    "Specifies how many instances are seen between tests." 
 "minNbSurvival"  ""  "--min-survival"  0   "The minimum number of candidates that should survive to continue one iteration." 
 "nbCandidates"  ""  "--num-candidates"  0   "The number of candidates that should be sampled and evaluated at each iteration." 
 "mu"  ""  "--mu"  5   "This value is used to determine the number of candidates to be sampled and evaluated at each iteration." 
